# Liara
Unofficial library for account management and services in [Liara](https://liara.ir) Cloud

### Quik start
```python
form liara import Client

client = Client(name='my_account')

result = client.get_my_account()
print(result)
```
